pub enum GithubError {
BadRequest,
ScrapeFailure(StatusCode),
ProfileNotFound(String),
}Expand description
A collection of error variants related to making a request to a Github profile page prior to scraping.
Variants
BadRequest
Represents a generic failure while trying to make a GET request to the specified Github profile page.
ScrapeFailure(StatusCode)
Represents a failure caused while attempting to scrape the specified Github profile page. This is typically caused by either a Github service outage, or any other kind of rejection (e.g rate-limiting, etc).
ProfileNotFound(String)
Represents a 404 response caused by attempting to scrape a non-existing Github profile page.