pub fn parse_slug(value: &str) -> Result<String, String>Expand description
Attempts to parse a Github profile slug, based on a regular expression typically used while restricting profile names. Assures that only valid profile slugs are being provided as an argument to Clap.
Errors
Returns an error if provided slug argument does not match regular expression.