pub struct ContributionWeek {
pub contributions: Vec<Option<Contribution>>,
}Expand description
A ContributionWeek instance represents an entire week of contributions
in a Github contribution heatmap. Typically visible as a column of heatmap
nodes on a Github profile page.
ContributionWeek instances are typically not constructed explicitly, rather created
implicitly by the higher level Heatmap struct via the from_days associated method.
Fields
contributions: Vec<Option<Contribution>>A vector of Contribution instances belonging to the week.
Contributions are wrapped in an Option, as years won’t necessarily begin and/or end on a Sunday, meaning that certain days may not be included in the heatmap during any given week.
Implementations
Sourceimpl ContributionWeek
impl ContributionWeek
Sourcepub fn from_days(days: &Vec<ElementRef<'_>>) -> Result<Self, HeatmapError>
pub fn from_days(days: &Vec<ElementRef<'_>>) -> Result<Self, HeatmapError>
Contructs a new ContributionWeek instance from a vector of HTML elements.
Provided vector corresponds to a collection of Github heatmap nodes.
For each valid day of the week with contributions, a Contribution instance
will be constructed and pushed to the contributions vector.
Errors
HeatmapError::QueryAttributefails to query y attributeHeatmapError::ParseAttributefails to parse y attributeHeatmapError::UnknownNodeFormatencounters unexpected heatmap node size while determining day of week for contributions
See Contribution for possible errors related to constructing a [‘Contribution’].