pub fn parse_year(value: &str) -> Result<String, String>Expand description
Attempts to parse a provided Year argument, based on simple regular expression. Assures that only valid calendar years are being provided as an argument to clap.
Errors
Returns an error if provided year argument does not match regular expression.